# A first dashboard

There is no setup needed for your first dashboard, thanks to the amazing [Py.Cafe](https://py.cafe/).

Follow the [Edit live on Py.Cafe](https://py.cafe/vizro-official/vizro-iris-analysis-0) link and you can see the code of the below dashboard and experiment with it.

<iframe src="https://py.cafe/embed/vizro-official/vizro-iris-analysis-0" width="100%" height="600px"></iframe>

<!-- vale off -->
## Can I break your code?
<!-- vale on -->
When you click the link to "Edit live on Py.Cafe" the dashboard is running inside your browser. Any changes you make are local and you don't need to worry about breaking the code for others. Nobody else sees the changes you make unless you save a copy of the project as your own Vizro py.cafe project.

<!-- vale off -->
## How can I make my own dashboards?
<!-- vale on -->
You can use [Py.Cafe](https://py.cafe/snippet/vizro/v1) to experiment with your own Vizro dashboards by dropping code onto a new project.

If you need inspiration or a starting point, we make all our examples available for you to try out on Py.Cafe. Throughout our documentation, follow the "**Run and edit this code in Py.Cafe**" link below the code snippets to open them in Py.Cafe.

## Where next?
You are now ready to explore Vizro further, by working through the ["Explore Vizro" tutorial](explore-components.md) or by consulting the [how-to guides](../user-guides/dashboard.md).
